@@ -1,13 +1,11 @@
-use v5.14;
 use warnings;
 use strict;
 use utf8;
 
-use Getopt::Long;
 use FindBin;
 use lib "$FindBin::Bin/../lib";
 use WWW::Scraper::F1;
-use Data::Dumper qw(Dumper);
+use Getopt::Long;
 
 my $upcoming = 1;
 my $top      = -1;
@@ -21,10 +19,17 @@ GetOptions(
 
 if ($upcoming){
    my $race_info = get_upcoming_race( ) ;
-   say "$race_info->{city}, $race_info->{country}\n$race_info->{countdown}\n";
+   print "$race_info->{city}, $race_info->{country}\n$race_info->{countdown}\n";
 }
 
-my $champ_info = get_top_championship( {length => $top, points => $points} );
+my $champ_info = get_top_championship( {length => $top} );
+
 foreach my $t (@$champ_info){
-   say "$t->{pos}. $t->{driver}\t $t->{points}"; 
+   if($points eq "no"){
+       print "$t->{pos}. $t->{driver}\n"; 
+   }elsif($points eq "just"){
+       print "$t->{points}\n";
+   }else{
+       print "$t->{pos}. $t->{driver}\t $t->{points}\n"; 
+   }
 }
